pub async fn lookup_all(
context: &Context,
namespace: Namespace,
) -> Result<Vec<String>>Expand description
Looks up all tokens from the given namespace, so that they can be used for decrypting a symmetrically-encrypted message.
The most-recently saved tokens are returned first. This improves performance when Bob scans a QR code that was just created.